<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Category;
use App\Models\Subcategory;
use App\Models\Product;
use App\Models\ProductImage;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use Illuminate\Support\Facades\File;
use Illuminate\Http\Response;
use Validator, Auth, DB, Hash;

class ProductController extends Controller
{
    public function index()
    {
        $productData = Product::all();
        $productDataPageVars = [
            //This is the title of my custom view.
            'pageTitle'=>'Product List',
            'productData'=>$productData
        ];
        return view('admin.pages.product.product-list')->with($productDataPageVars);
    }

    public function view()
    {
        $category = Category::select('id', 'category_name')->get();
        return view('admin.pages.product.add-product', compact('category'));
    }

    public function ajaxSubCategory(Request $request)
    {
        $parent_id = $request->cat_id;
        $subcategories = Subcategory::where('cat_id', '=', $parent_id)->get();

        return response()->json(['subcategories' => $subcategories]);
    }

    public function store(Request $request)
    {
        $data = $request->all();
        // dd($data);
        $rules = [
            'cat_id' => ['required'],
            'sub_cat_id' => ['required'],
            'product_name' => ['required', 'string', 'min:3', 'max:150'],
            'product_price' => ['required', 'numeric', 'gt:0'],
            'discount_price' => ['numeric', 'lt:product_price'],
            'sku' => ['required'],
            // 'status' => ['required']
        ];

        $message = [
            'cat_id.required' => 'Category name is required.',
            'sub_cat_id.required' => 'Subcategory name is required.',
            'product_name.required' => 'Product name is required.',
            'product_name.min' => 'Product name must be 2 characters minimum.',
            'product_name.max' => 'Product name must be 2 characters maximum.',
            'product_price.required' => 'Product price is required.',
            'product_price.numeric' => 'Product price must be numeric.',
            'product_price.gt' => 'Product price must be greater then 0.',
            'discount_price.numeric' => 'Discount price must be numeric.',
            'discount_price.lt' => 'Discount price must be less then product price.',
            'sku.required' => 'Product Code / SKU is required.',
            // 'status.required' => 'Status field is required.'
        ];

        // $validator = Validator::make($data, $rules, $message);
        // if($validator->fails()) {
        //     return redirect('admin/product')
        //                 ->withErrors($validator)
        //                 ->withInput();
        // }
        $first_image = '';
        // dd($request->product_images);
        // dd($first_image);

        $slugname = $this->generateSlug($request->product_name, $request->cat_id, $request->sub_cat_id);
        
        $tax_rate = isset($data['tax_rate']) ? $data['tax_rate'] : 0;
        $manage_stock = isset($data['manage_stock']) ? $data['manage_stock'] : 0;
        $stock_quantity = isset($data['stock_quantity']) ? $data['stock_quantity'] : 0;
        $stock_status = isset($data['stock_status']) ? $data['stock_status'] : 0;
        $is_free_shipping = isset($data['is_free_shipping']) ? $data['is_free_shipping'] : 0;
        $status = isset($data['status']) ? $data['status'] : 707;
        $sort_order = isset($data['sort_order']) ? $data['sort_order'] : 0;

        $product = new Product;
        $product->cat_id = $data['cat_id'];
        $product->sub_cat_id = $data['sub_cat_id'];
        $product->product_name = $data['product_name'];
        $product->slug = $slugname;
        $product->sku = $data['sku'];
        $product->product_price = $data['product_price'];
        $product->discount_price = $data['discount_price'];
        $product->net_price = $data['net_price'];
        $product->minimum_order_quantity = $data['minimum_order_quantity'];
        $product->tax_included = $data['tax_included'];
        $product->tax_rate = $tax_rate;
        $product->manage_stock = $manage_stock;
        $product->stock_quantity = $stock_quantity;
        $product->stock_status = $stock_status;
        $product->short_description = $data['short_description'];
        $product->description = $data['description'];
        $product->product_main_images = $first_image;
        $product->product_weight = $data['product_weight'];
        $product->is_free_shipping = $is_free_shipping;
        $product->estimated_shipping_days = $data['estimated_shipping_days'];
        $product->estimated_outofstock_shipping_days = $data['estimated_outofstock_shipping_days'];
        $product->days_allowed_to_return = $data['days_allowed_to_return'];
        $product->is_label = $data['is_label'];
        $product->custom_label_name = $data['custom_label_name'];
        $product->video_type = $data['video_type'];
        $product->video_code = $data['video_code'];
        $product->vimeo_code = $data['vimeo_code'];
        $product->meta_title = $data['meta_title'];
        $product->meta_keyword = $data['meta_keyword'];
        $product->meta_description = $data['meta_description'];
        $product->status = $status;
        $product->sort_order = $sort_order;

        $product->save();
        
        if($request->hasfile('product_images'))
        {
            foreach($request->file('product_images') as $filekey => $file)
            {
                // $first_image = time().'.'.$file->extension();
                // $file->move(public_path('products'), $first_image);

                $productImage = new ProductImage();
                $productImage->product_id = $product->id;
                $productImage->product_image_name = $file->getClientOriginalName();
                $first_image = $filekey.'-'.time().'.'.$file->extension();
                $file->move(public_path('products'), $first_image);
                $productImage->product_image = $first_image;
                $productImage->save();
                
            }
        }

        return redirect('admin/product/displayproduct')->with('success','Product added successfully.');
    }

    public function show($id){
        $category = Category::select('id', 'category_name')->get();
        // $subcategory = Subcategory::find($id);
        $product = Product::find($id);
        return view('admin.pages.product.edit-product', compact('product','category'));
    }

    public function update(Request $request)
    {
        $data = $request->all();
        $productId = $data['id'];
        // dd($data);
        $rules = [
            'cat_id' => ['required'],
            'sub_cat_id' => ['required'],
            'product_name' => ['required', 'string', 'min:3', 'max:150'],
            'product_price' => ['required', 'numeric', 'gt:0'],
            'discount_price' => ['numeric', 'lt:product_price'],
            'sku' => ['required'],
            // 'status' => ['required']
        ];

        $message = [
            'cat_id.required' => 'Category name is required.',
            'sub_cat_id.required' => 'Subcategory name is required.',
            'product_name.required' => 'Product name is required.',
            'product_name.min' => 'Product name must be 2 characters minimum.',
            'product_name.max' => 'Product name must be 2 characters maximum.',
            'product_price.required' => 'Product price is required.',
            'product_price.numeric' => 'Product price must be numeric.',
            'product_price.gt' => 'Product price must be greater then 0.',
            'discount_price.numeric' => 'Discount price must be numeric.',
            'discount_price.lt' => 'Discount price must be less then product price.',
            'sku.required' => 'Product Code / SKU is required.',
            // 'status.required' => 'Status field is required.'
        ];

        $validator = Validator::make($data, $rules, $message);
        if($validator->fails()) {
            return redirect('admin/product')
                        ->withErrors($validator)
                        ->withInput();
        }

        $first_image = '';
        $slugname = $this->generateSlug($request->product_name, $request->cat_id, $request->sub_cat_id);
        
        $tax_rate = isset($data['tax_rate']) ? $data['tax_rate'] : 0;
        $manage_stock = isset($data['manage_stock']) ? $data['manage_stock'] : 0;
        $stock_quantity = isset($data['stock_quantity']) ? $data['stock_quantity'] : 0;
        $stock_status = isset($data['stock_status']) ? $data['stock_status'] : 0;
        $is_free_shipping = isset($data['is_free_shipping']) ? $data['is_free_shipping'] : 0;
        $status = isset($data['status']) ? $data['status'] : 707;
        $sort_order = isset($data['sort_order']) ? $data['sort_order'] : 0;

        $result = Product::where('id', "=", $productId)
                    ->update([
                        'sub_cat_id' => $data['sub_cat_id'],
                        'cat_id' => $data['cat_id'],
                        'product_name' => $data['product_name'],
                        // 'slug' => $slugname,
                        'sku' => $data['sku'],
                        'product_price' => $data['product_price'],
                        'discount_price' => $data['discount_price'],
                        'net_price' => $data['net_price'],
                        'minimum_order_quantity' => $data['minimum_order_quantity'],
                        'tax_included' => $data['tax_included'],
                        'tax_rate' => $tax_rate,
                        'manage_stock' => $manage_stock,
                        'stock_quantity' => $stock_quantity,
                        'stock_status' => $stock_status,
                        'short_description' => $data['short_description'],
                        'description' => $data['description'],
                        'product_main_images' => $first_image,
                        'product_weight' => $data['product_weight'],
                        'is_free_shipping' => $is_free_shipping,
                        'estimated_shipping_days' => $data['estimated_shipping_days'],
                        'estimated_outofstock_shipping_days' => $data['estimated_outofstock_shipping_days'],
                        'days_allowed_to_return' => $data['days_allowed_to_return'],
                        'is_label' => $data['is_label'],
                        'custom_label_name' => $data['custom_label_name'],
                        'video_type' => $data['video_type'],
                        'video_code' => $data['video_code'],
                        'vimeo_code' => $data['vimeo_code'],
                        'meta_title' => $data['meta_title'],
                        'meta_keyword' => $data['meta_keyword'],
                        'meta_description' => $data['meta_description']
                    ]);

        if($result){
            return redirect('admin/product/displayproduct/')->with('success','Product updated successfully.');
        }else{
            return redirect('admin/product/'.$productId)->with('error','Product data is not updated!');
        }
    }

    public function productimageupload(Request $request, $id){
        $data = $request->all();
        $productId = $id;
        if($request->hasfile('product_images'))
        {
            foreach($request->file('product_images') as $filekey => $file)
            {
                // $first_image = time().'.'.$file->extension();
                // $file->move(public_path('products'), $first_image);

                $productImage = new ProductImage();
                $productImage->product_id = $productId;
                $productImage->product_image_name = $file->getClientOriginalName();
                $first_image = $filekey.'-'.time().'.'.$file->extension();
                $file->move(public_path('products'), $first_image);
                $productImage->product_image = $first_image;
                $productImage->save();

                if($productImage){
                    return response()->json(['nothing' => true]);
                }else{
                    return response()->json(['nothing' => false]);
                }
            }
        }
    }

    public function productimagedelete($id){
        $productdata = ProductImage::select('product_image')->where('id', "=", $id)->get();
        $productimageName = $productdata[0]->product_image;
        File::delete('products/'.$productimageName);

        $result = ProductImage::where('id', '=', $id)->delete();

        if($result){
            return response()->json(['message' => "Deleted file 1 successfully!"]);
        }else{
            return response()->json(['message' => "File not deleted"]);
        }

    }

    public function delete($id){
        $productImagesdata = ProductImage::where('product_id', "=", $id)->get();
        
        foreach($productImagesdata as $singleProduct) {
            $productImage = $singleProduct->product_image;
            File::delete('products/'.$productImage);
        }

        $deleteproductImages = ProductImage::where('product_id', '=', $id)->delete();
        $deleteproduct = Product::where('id', '=', $id)->delete();

        if($deleteproduct){
            return redirect('admin/product/displayproduct')->with('success','Product record deleted successfully!');
        }
    }

    private function generateSlug($name, $catId, $subcatId)
    {
        if (Product::whereSlug($slug = Str::slug($name))->where([['cat_id', '=', $catId], ['sub_cat_id', '=', $subcatId]])->exists()) {
            $max = Product::where([["product_name", "=", $name], ['cat_id', '=', $catId], ['sub_cat_id', '=', $subcatId]])->latest('id')->skip(1)->value('slug');
            if (isset($max[-1]) && is_numeric($max[-1])) {
                return preg_replace_callback('/(\d+)$/', function($mathces) {
                    return $mathces[1] + 1;
                }, $max);
            }
            return "{$slug}-2";
        }
        return $slug;
    }
}
