<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Subcategory;
use App\Models\Category;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use Illuminate\Support\Facades\File; 
use Validator, Auth, DB, Hash;

class SubcategoryController extends Controller
{
    public function index()
    {
        $subcategoryData = Subcategory::all();
        $subcategoryPageVars = [
            //This is the title of my custom view.
            'pageTitle'=>'Sub Category List',
            'subcategoryData'=>$subcategoryData
        ];
        return view('admin.pages.subcategories.sub-category-list')->with($subcategoryPageVars);
    }

    public function view()
    {
        $category = Category::select('id', 'category_name')->get();
        return view('admin.pages.subcategories.add-sub-category', compact('category'));
    }
    
    public function store(Request $request)
    {
        $data = $request->all();
        $rules = [
            'cat_id' => ['required'],
            'sub_category_name' => ['required', 'string', 'min:3', 'max:50'],
            'status' => ['required']
        ];

        $message = [
            'cat_id.required' => 'Category name field is required.',
            'sub_category_name.required' => 'Sub category name field is required.',
            'status.required' => 'Status field is required.'
        ];

        $validator = Validator::make($data, $rules, $message);
        if($validator->fails()) {
            return redirect('admin/subcategory')
                        ->withErrors($validator)
                        ->withInput();
        }

        $subcategoryStore = Subcategory::create([
            "cat_id" => $data['cat_id'],
            "sub_category_name" => $data['sub_category_name'],
            "status" => $data['status']
        ]); 

        return redirect('admin/subcategory/displaysubcategory')->with('success','Subcategory added successfully.');
    }

    public function show($id){
        $category = Category::select('id', 'category_name')->get();
        $subcategory = Subcategory::find($id);
        return view('admin.pages.subcategories.edit-sub-category', compact('subcategory','category'));
    }

    public function update(Request $request)
    {
        $data = $request->all();
        $subCatId = $data['sub_cat_id'];
        $catId = $data['cat_id'];
        $rules = [
            'cat_id' => ['required'],
            'sub_category_name' => ['required', 'string', 'min:3', 'max:50'],
            'status' => ['required']
        ];

        $message = [
            'cat_id.required' => 'Category name field is required.',
            'sub_category_name.required' => 'Sub category name field is required.',
            'status.required' => 'Status field is required.'
        ];
        $validator = Validator::make($data, $rules, $message);
        if($validator->fails()) {
            return redirect('admin/subcategory/'.$subCatId)
                        ->withErrors($validator)
                        ->withInput();
        }

        $subcategorygetdata = Subcategory::select('cat_id', 'sub_category_name')->where('id', "=", $subCatId)->get();
        $singlesubcategoryname = $subcategorygetdata[0]->sub_category_name;
        if($singlesubcategoryname != $request->sub_category_name){
            $slugname = $this->generateSlug($request->sub_category_name, $catId);
            $result = Subcategory::where('id', "=", $subCatId)
                    ->update(['slug' => $slugname]);
        }

        $result = Subcategory::where('id', "=", $subCatId)
                    ->update(['cat_id' => $data['cat_id'], 'sub_category_name' => $data['sub_category_name'], 'status' => $data['status']]);

        if($result){
            return redirect('admin/subcategory/displaysubcategory/')->with('success','Subcategory updated successfully.');
        }else{
            return redirect('admin/subcategory/'.$subCatId)->with('error','Subcategory data is not updated!');
        }
    }

    public function delete($id){
        $result = Subcategory::where('id', '=', $id)->delete();

        if($result){
            return redirect('admin/subcategory/displaysubcategory')->with('success','Subcategory record deleted successfully!');
        }
    }

    private function generateSlug($name, $catId)
    {
        if (Subcategory::whereSlug($slug = Str::slug($name))->where('cat_id', '=', $catId)->exists()) {
            $max = Subcategory::where(["sub_category_name", "=", $name, 'cat_id', '=', $catId])->latest('id')->skip(1)->value('slug');
            if (isset($max[-1]) && is_numeric($max[-1])) {
                return preg_replace_callback('/(\d+)$/', function($mathces) {
                    return $mathces[1] + 1;
                }, $max);
            }
            return "{$slug}-2";
        }
        return $slug;
    }
}
