<?php

namespace App\Http\Controllers;

use App\Models\User;
use App\Models\Address;
use App\Models\Order;
use App\Models\OrderDetail;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Session;
use Validator, Auth, DB, Hash;

class CheckoutController extends Controller
{
    public function __construct()
    {
        // $this->middleware('auth');
    }

    public function checkoutView()
    {
        $cartItems = \Cart::getContent();
        // dd($cartItems);
        return view('front.pages.checkout', compact('cartItems'));
    }

    public function checkoutSave(Request $request)
    {
        $cartItems = \Cart::getContent();
        $cartTotalAmount = \Cart::getTotal();
        // dd($cartItems);

        $data = $request->all();
        // dd($data);
        $rules = [
            'email' => ['required', 'email', 'max:255', 'unique:users'],
            'shipping_first_name' => ['required', 'string', 'min:2', 'max:50'],
            'shipping_last_name' => ['required', 'string', 'min:2', 'max:50'],
            'shipping_phone' => ['required', 'numeric', 'min:10'],
            'shipping_address' => ['required', 'string', 'min:2', 'max:500'],
            'shipping_country' => ['required'],
            'shipping_state' => ['required'],
            'shipping_city' => ['required'],
            'shipping_zip' => ['required', 'numeric', 'min:5'],
            'billing_first_name' => ['required', 'string', 'min:2', 'max:50'],
            'billing_last_name' => ['required', 'string', 'min:2', 'max:50'],
            'billing_phone' => ['required', 'numeric', 'min:10'],
            'billing_address' => ['required', 'string', 'min:2', 'max:500'],
            'billing_country' => ['required'],
            'billing_state' => ['required'],
            'billing_city' => ['required'],
            'billing_zip' => ['required', 'numeric', 'min:5'],
            'is_agree_terms' => ['required']
        ];

        $message = [
            'email.required' => 'Email field is required.',
            'email.email' => 'Email field must be email format.',
            'email.max' => 'Email field must be use max 255 characters.',
            'email.unique' => 'Email is already exist. Try another email id.',
            'shipping_first_name.required' => 'First name field is required.',
            'shipping_first_name.string' => 'First name field must be string format.',
            'shipping_first_name.min' => 'First name field must be use min 2 characters.',
            'shipping_first_name.max' => 'First name field must be use max 50 characters.',
            'shipping_last_name.required' => 'Last name field is required.',
            'shipping_last_name.string' => 'Last name field must be string format.',
            'shipping_last_name.min' => 'Last name field must be use min 2 characters.',
            'shipping_last_name.max' => 'Last name field must be use max 50 characters.',
            'shipping_phone.required' => 'Mobile field is required.',
            'shipping_phone.numeric' => 'Mobile field must be number format.',
            'shipping_phone.min' => 'Mobile field must be use min 10 characters.',
            // 'shipping_phone.max' => 'Mobile field must be use max 10 characters.',
            'shipping_address.required' => 'Address field is required.',
            'shipping_address.string' => 'Address field must be string format.',
            'shipping_address.min' => 'Address field must be use min 2 characters.',
            'shipping_address.max' => 'Address field must be use max 500 characters.',
            'shipping_country.required' => 'Country field is required.',
            'shipping_state.required' => 'State field is required.',
            'shipping_city.required' => 'City field is required.',
            'shipping_zip.required' => 'Zip code field is required.',
            'shipping_zip.numeric' => 'Zip code field must be number format.',
            'shipping_zip.min' => 'Zip code field must be use min 5 characters.',
            // 'shipping_zip.max' => 'Zip code field must be use max 8 characters.',
            'billing_first_name.required' => 'First name field is required.',
            'billing_first_name.string' => 'First name field must be string format.',
            'billing_first_name.min' => 'First name field must be use min 2 characters.',
            'billing_first_name.max' => 'First name field must be use max 50 characters.',
            'billing_last_name.required' => 'Last name field is required.',
            'billing_last_name.string' => 'Last name field must be string format.',
            'billing_last_name.min' => 'Last name field must be use min 2 characters.',
            'billing_last_name.max' => 'Last name field must be use max 50 characters.',
            'billing_phone.required' => 'Mobile field is required.',
            'billing_phone.numeric' => 'Mobile field must be number format.',
            'billing_phone.min' => 'Mobile field must be use min 10 characters.',
            // 'billing_phone.max' => 'Mobile field must be use max 10 characters.',
            'billing_address.required' => 'Address field is required.',
            'billing_address.string' => 'Address field must be string format.',
            'billing_address.min' => 'Address field must be use min 2 characters.',
            'billing_address.max' => 'Address field must be use max 500 characters.',
            'billing_country.required' => 'Country field is required.',
            'billing_state.required' => 'State field is required.',
            'billing_city.required' => 'City field is required.',
            'billing_zip.required' => 'Zip code field is required.',
            'billing_zip.numeric' => 'Zip code field must be number format.',
            'billing_zip.min' => 'Zip code field must be use min 5 characters.',
            // 'billing_zip.max' => 'Zip code field must be use max 8 characters.',
            'is_agree_terms.required' => 'Terms & Conditions field is required.'
        ];

        $validator = Validator::make($data, $rules, $message);
        if($validator->fails()) {
            return redirect('checkout')
                        ->withErrors($validator)
                        ->withInput();
        }

        $userCreate = new User;
        $userCreate->first_name = $data['billing_first_name'];
        $userCreate->last_name = $data['billing_last_name'];
        $userCreate->email = $data['email'];
        $userCreate->password = Hash::make($data['password']);
        $userCreate->mobile = $data['billing_phone'];
        $userCreate->save();

        $userId = $userCreate->id;

        $userAddressCreate = new Address();
        $userAddressCreate->user_id = $userId;
        $userAddressCreate->address = $data['billing_address'];
        $userAddressCreate->country_id = $data['billing_country'];
        $userAddressCreate->state_id = $data['billing_state'];
        $userAddressCreate->city = $data['billing_city'];
        $userAddressCreate->zip_code = $data['billing_zip'];
        $userAddressCreate->default_address = 1;
        $userAddressCreate->address_type = "Home";
        $userAddressCreate->save();
        
        $getMaxOrderNo = Order::max('order_no');
        $addOderNo = $getMaxOrderNo + 1;
        $date = Carbon::now();
        $couponCode = "";

        $orderCreate = new Order();
        $orderCreate->user_id = $userId;
        $orderCreate->order_no = $addOderNo;
        $orderCreate->currency_id = 1;
        $orderCreate->currency_symbol = "USD";
        $orderCreate->currency_value = 1;
        $orderCreate->shipping_first_name = $data['shipping_first_name'];
        $orderCreate->shipping_last_name = $data['shipping_last_name'];
        $orderCreate->shipping_phone = $data['shipping_phone'];
        $orderCreate->shipping_address = $data['shipping_address'];
        $orderCreate->shipping_country_id = $data['shipping_country'];
        $orderCreate->shipping_state_id = $data['shipping_state'];
        $orderCreate->shipping_city = $data['shipping_city'];
        $orderCreate->shipping_zip_code = $data['shipping_zip'];
        $orderCreate->billing_first_name = $data['billing_first_name'];
        $orderCreate->billing_last_name = $data['billing_last_name'];
        $orderCreate->billing_phone = $data['billing_phone'];
        $orderCreate->billing_address = $data['billing_address'];
        $orderCreate->billing_country_id = $data['billing_country'];
        $orderCreate->billing_state_id = $data['billing_state'];
        $orderCreate->billing_city = $data['billing_city'];
        $orderCreate->billing_zip_code = $data['billing_zip'];
        $orderCreate->shipping_amount = 0;
        $orderCreate->total_order_amount = $cartTotalAmount;
        $orderCreate->coupon_discount_amoount = 0;
        $orderCreate->coupon_number = $couponCode;
        $orderCreate->status = 505;
        $orderCreate->payment_status = 505;
        $orderCreate->shipping_status = 505;
        $orderCreate->order_date = $date;
        $orderCreate->save();

        $sessionId = Session::getId();
        $cartItemsLength = count($cartItems);
        foreach($cartItems as $key => $item){
            $orderDetailCreate = new OrderDetail();
            $orderDetailCreate->user_id = $userId;
            $orderDetailCreate->order_no = $addOderNo;
            $orderDetailCreate->session_id = $sessionId;
            $orderDetailCreate->product_id = $item['id'];
            $orderDetailCreate->cat_id = $item['attributes']['catid'];
            $orderDetailCreate->sub_cat_id = $item['attributes']['subcatid'];
            $orderDetailCreate->product_name = $item['name'];
            $orderDetailCreate->order_quantity = $item['quantity'];
            $orderDetailCreate->product_price = $item['price'];
            $orderDetailCreate->product_image = $item['attributes']['image'];
            $orderDetailCreate->order_date = $date;
            $orderDetailCreate->save();
        }

        // if($orderCreate){
            \Cart::clear();
            $credentials = $request->only('email', 'password');
            if (Auth::attempt($credentials)) {
                return redirect('payment/'.$addOderNo)->withSuccess('success');
                // return redirect()->route('payment',['order_no'=>$addOderNo]);
                // return redirect()->route('front.pages.place-order');
            }
            // if (Auth::guard('web')->attempt(['email' => $request->email, 'password' => $request->password])) {

            //     return redirect()->route('front.pages.place-order');
    
            // }
            // return redirect('checkout');
        // }

    }

    public function paymentview($orderno)
    {
        // dd('aaaaaaaaaaaa',$orderno);
        $orderDetails = OrderDetail::where('order_no', '=', $orderno)->get();
        $order = Order::where('order_no', '=', $orderno)->get();
        $getUserId = $order[0]['user_id'];
        $user = User::where('id', '=', $getUserId)->get();
        return view('front.pages.place-order', compact('orderDetails','order','user'));
    }
}
