<?php

namespace App\Models;

use Illuminate\Support\Str;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Category extends Model
{
    use HasFactory;
    protected $fillable = [ 
        'category_name', 
        'slug',
        'category_image',
        'status' 
    ];
    public $timestamps = true;

    protected static function boot()
    {
        parent::boot();
        static::created(function ($categoryStore) {
            $categoryStore->slug = $categoryStore->generateSlug($categoryStore->category_name);
            $categoryStore->save();
        });
    }

    private function generateSlug($name)
    {
        if (static::whereSlug($slug = Str::slug($name))->exists()) {
            $max = static::where("category_name", "=", $name)->latest('id')->skip(1)->value('slug');
            if (isset($max[-1]) && is_numeric($max[-1])) {
                return preg_replace_callback('/(\d+)$/', function($mathces) {
                    return $mathces[1] + 1;
                }, $max);
            }
            return "{$slug}-2";
        }
        return $slug;
    }

    public function subcategories(){
        return $this->hasMany(Subcategory::class, 'cat_id', 'id');
    }

    public function products(){
        return $this->hasMany(Product::class, 'cat_id', 'id');
    }
}
