<?php

namespace App\Models;

use Illuminate\Support\Str;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Subcategory extends Model
{
    use HasFactory;
    protected $table = 'sub_categories';

    protected $fillable = [ 
        'cat_id',
        'sub_category_name', 
        'slug',
        'status' 
    ];
    public $timestamps = true;

    protected static function boot()
    {
        parent::boot();
        static::created(function ($subCategoryStore) {
            $subCategoryStore->slug = $subCategoryStore->generateSlug($subCategoryStore->sub_category_name, $subCategoryStore->cat_id);
            $subCategoryStore->save();
        });
    }

    private function generateSlug($name, $catId)
    {
        // dd($name, $catId);
        if (static::whereSlug($slug = Str::slug($name))->where('cat_id', '=', $catId)->exists()) {
            $max = static::where(["sub_category_name", "=", $name, 'cat_id', '=', $catId])->latest('id')->skip(1)->value('slug');
            if (isset($max[-1]) && is_numeric($max[-1])) {
                return preg_replace_callback('/(\d+)$/', function($mathces) {
                    return $mathces[1] + 1;
                }, $max);
            }
            return "{$slug}-2";
        }
        return $slug;
    }

    public function categories()
    {
        return $this->belongsTo(Category::class, 'cat_id');
    }

    public function products(){
        return $this->hasMany(Product::class, 'sub_cat_id', 'id');
    }
}
