<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('products', function (Blueprint $table) {
            $table->increments('id');
            $table->foreignId('cat_id')->constrained('categories')->onUpdate('cascade')->onDelete('cascade');
            $table->unsignedInteger('sub_cat_id')->nullable();
            $table->string('product_name', 250);
            $table->string('slug', 250)->nullable();
            $table->string('sku', 150)->nullable();
            $table->decimal('product_price', 5, 2);
            $table->decimal('discount_price', 5, 2)->nullable();
            $table->decimal('net_price', 5, 2)->nullable();
            $table->integer('minimum_order_quantity')->nullable();
            $table->integer('tax_included')->default(0);
            $table->decimal('tax_rate', 5, 2)->nullable();
            $table->boolean('manage_stock')->default(false);
            $table->integer('stock_quantity')->nullable();
            $table->integer('stock_status')->default(0);
            $table->mediumText('short_description')->nullable();
            $table->longText('description')->nullable();
            $table->string('product_main_images', 255)->nullable();
            $table->decimal('product_weight', 5, 2)->nullable();
            $table->mediumInteger('is_free_shipping')->default(0);
            $table->integer('estimated_shipping_days')->default(0);
            $table->integer('estimated_outofstock_shipping_days')->default(0);
            $table->integer('days_allowed_to_return')->default(0);
            $table->integer('is_label')->default(2);
            $table->string('custom_label_name', 150)->nullable();
            $table->integer('video_type')->nullable();
            $table->string('video_code', 255)->nullable();
            $table->string('vimeo_code', 255)->nullable();
            $table->string('meta_title', 255)->nullable();
            $table->string('meta_keyword', 255)->nullable();
            $table->string('meta_description', 255)->nullable();
            $table->mediumInteger('status')->default(707);
            $table->mediumInteger('sort_order')->default(0);
            $table->timestamps();
            $table->foreign('sub_cat_id')->references('id')->on('sub_categories');
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        // Schema::dropIfExists('products');
        Schema::table('products', function (Blueprint $table) {
            $table->dropForeign(['cat_id']);
            // $table->dropForeign(['sub_cat_id']);
        });
    }
};
